.. FabIO documentation master file, created by
   sphinx-quickstart on Fri Mar 15 09:03:50 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to FabIO's documentation!
=================================

FabIO is an I/O library for images produced by 2D X-ray detectors and written in Python.
FabIO support images detectors from a dozen of companies (including Mar, Dectris, ADSC, Hamamatsu, Oxford, ...),
for a total of 30 different file formats (like CBF, EDF, TIFF, ...) and offers an unified interface to their
headers (as a python dictionary) and datasets (as a numpy ndarray of integers or floats)



Contents:

.. toctree::
   :maxdepth: 1

   getting_started
   install
   tutorials/index
   performances
   Changelog
   man/fabio_viewer
   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

